You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tiles.apache.org by ap...@apache.org on 2007/09/07 20:09:43 UTC

svn commit: r573651 - in /tiles/framework/branches/TILES_2_0_X: tiles-core/src/main/java/org/apache/tiles/servlet/context/ tiles-core/src/test/java/org/apache/tiles/impl/ tiles-core/src/test/java/org/apache/tiles/servlet/context/ tiles-test/src/main/we...

Author: apetrelli
Date: Fri Sep  7 11:09:41 2007
New Revision: 573651

URL: http://svn.apache.org/viewvc?rev=573651&view=rev
Log:
Merge from trunk to TILES_2_0_X branch.
TILES-210
Added directive to JSP pages to prevent session creation if not needed.
TILES-207
Now ServletSessionScopeMap points to a request and creates a session only if needed.

Added:
    tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java   (contents, props changed)
      - copied, changed from r573035, tiles/framework/trunk/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java
Modified:
    tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletSessionScopeMap.java
    tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletTilesRequestContext.java
    tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/impl/KeyedDefinitionsFactoryTilesContainerTest.java
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/body.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/classpath.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/defaultlocale.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/exception.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/header.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/index.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout_flush.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/override.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putallattributeslayout.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putattributeslayout.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/selectlocale.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdecorationfilter.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_extend.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_preparer.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute_all.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinitcontainer.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_classpath.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured_notype.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_notype.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_exception.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_flush.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_freemarker.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_inline.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override_and_not.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer_configured.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_el.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_flush.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_servlet.jsp
    tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testputlist.jsp

Modified: tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletSessionScopeMap.java
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletSessionScopeMap.java?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletTilesRequestContext.java (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletTilesRequestContext.java Fri Sep  7 11:09:41 2007
@@ -171,7 +171,7 @@
     public Map<String, Object> getSessionScope() {
 
         if ((sessionScope == null) && (request != null)) {
-            sessionScope = new ServletSessionScopeMap(request.getSession());
+            sessionScope = new ServletSessionScopeMap(request);
         }
         return (sessionScope);
 

Modified: tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/impl/KeyedDefinitionsFactoryTilesContainerTest.java
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/impl/KeyedDefinitionsFactoryTilesContainerTest.java?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/impl/KeyedDefinitionsFactoryTilesContainerTest.java (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/impl/KeyedDefinitionsFactoryTilesContainerTest.java Fri Sep  7 11:09:41 2007
@@ -188,7 +188,7 @@
         EasyMock.reset(request);
         EasyMock.reset(session);
         EasyMock.reset(response);
-        EasyMock.expect(request.getSession()).andReturn(session).anyTimes();
+        EasyMock.expect(request.getSession(false)).andReturn(session).anyTimes();
         EasyMock.expect(session.getAttribute(DefaultLocaleResolver.LOCALE_KEY)).andReturn(null).anyTimes();
         EasyMock.expect(request.getLocale()).andReturn(null).anyTimes();
         EasyMock.expect(request.getAttribute(
@@ -207,7 +207,7 @@
         EasyMock.expect(request.getAttribute(
                 DefaultKeyExtractor.DEFINITIONS_FACTORY_KEY_ATTRIBUTE_NAME))
                 .andReturn("one").anyTimes();
-        EasyMock.expect(request.getSession()).andReturn(session).anyTimes();
+        EasyMock.expect(request.getSession(false)).andReturn(session).anyTimes();
         EasyMock.expect(session.getAttribute(DefaultLocaleResolver.LOCALE_KEY)).andReturn(null).anyTimes();
         EasyMock.expect(request.getLocale()).andReturn(null).anyTimes();
         EasyMock.replay(request);
@@ -223,7 +223,7 @@
         EasyMock.expect(request.getAttribute(
                 DefaultKeyExtractor.DEFINITIONS_FACTORY_KEY_ATTRIBUTE_NAME))
                 .andReturn("two").anyTimes();
-        EasyMock.expect(request.getSession()).andReturn(session).anyTimes();
+        EasyMock.expect(request.getSession(false)).andReturn(session).anyTimes();
         EasyMock.expect(session.getAttribute(DefaultLocaleResolver.LOCALE_KEY)).andReturn(null).anyTimes();
         EasyMock.expect(request.getLocale()).andReturn(null).anyTimes();
         EasyMock.replay(request);

Copied: tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java (from r573035, tiles/framework/trunk/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java)
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java?p2=tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java&p1=tiles/framework/trunk/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java&r1=573035&r2=573651&rev=573651&view=diff
==============================================================================
    (empty)

Propchange: tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: tiles/framework/branches/TILES_2_0_X/tiles-core/src/test/java/org/apache/tiles/servlet/context/ServletSessionScopeMapTest.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/body.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/body.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/body.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/body.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/classpath.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/classpath.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/classpath.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/classpath.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/defaultlocale.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/defaultlocale.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/defaultlocale.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/defaultlocale.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/exception.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/exception.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/exception.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/exception.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/header.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/header.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/header.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/header.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/index.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/index.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/index.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/index.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <!--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout_flush.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout_flush.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout_flush.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/layout_flush.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/override.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/override.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/override.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/override.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putallattributeslayout.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putallattributeslayout.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putallattributeslayout.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putallattributeslayout.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putattributeslayout.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putattributeslayout.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putattributeslayout.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/putattributeslayout.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/selectlocale.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/selectlocale.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/selectlocale.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/selectlocale.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <%--
 /*

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdecorationfilter.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdecorationfilter.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdecorationfilter.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdecorationfilter.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_extend.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_extend.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_extend.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_extend.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_preparer.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_preparer.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_preparer.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testdef_preparer.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute_all.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute_all.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute_all.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testimportattribute_all.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinitcontainer.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinitcontainer.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinitcontainer.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinitcontainer.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_classpath.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_classpath.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_classpath.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_classpath.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured_notype.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured_notype.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured_notype.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_includes_configured_notype.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_notype.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_notype.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_notype.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_composite_tags_notype.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_exception.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_exception.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_exception.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_exception.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_flush.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_flush.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_flush.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_flush.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_freemarker.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_freemarker.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_freemarker.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_freemarker.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_inline.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_inline.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_inline.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_inline.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override_and_not.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override_and_not.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override_and_not.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_override_and_not.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer_configured.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer_configured.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer_configured.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testinsertdefinition_preparer_configured.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_el.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_el.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_el.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_el.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_flush.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_flush.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_flush.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_flush.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_servlet.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_servlet.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_servlet.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testput_servlet.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$

Modified: tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testputlist.jsp
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testputlist.jsp?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================
--- tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testputlist.jsp (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-test/src/main/webapp/testputlist.jsp Fri Sep  7 11:09:41 2007
@@ -1,3 +1,4 @@
+<%@ page session="false" %>
 <%--
 /*
  * $Id$
--- tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletSessionScopeMap.java (original)
+++ tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletSessionScopeMap.java Fri Sep  7 11:09:41 2007
@@ -28,6 +28,7 @@
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import javax.servlet.http.HttpServletRequest;
 
 import javax.servlet.http.HttpSession;
 
@@ -46,30 +47,36 @@
     /**
      * Constructor.
      *
      * @param session The session object to use.
      */
-    public ServletSessionScopeMap(HttpSession session) {
-        this.session = session;
+    public ServletSessionScopeMap(HttpServletRequest request) {
+        this.request = request;
     }
 
-
     /**
      * The session object to use.
      */
-    private HttpSession session = null;
-
+    private HttpServletRequest request = null;
 
     /** {@inheritDoc} */
     public void clear() {
-        Iterator<String> keys = keySet().iterator();
-        while (keys.hasNext()) {
-            session.removeAttribute(keys.next());
+        HttpSession session = request.getSession(false);
+        if (session != null) {
+            Iterator<String> keys = keySet().iterator();
+            while (keys.hasNext()) {
+                session.removeAttribute(keys.next());
+            }
         }
     }
 
 
     /** {@inheritDoc} */
     public boolean containsKey(Object key) {
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return false;
+        }
+
         return (session.getAttribute(key(key)) != null);
     }
 
@@ -77,7 +84,8 @@
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     public boolean containsValue(Object value) {
-        if (value == null) {
+        HttpSession session = request.getSession(false);
+        if (session == null || value == null) {
             return (false);
         }
         Enumeration<String> keys = session.getAttributeNames();
@@ -94,13 +102,16 @@
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     public Set<Map.Entry<String, Object>> entrySet() {
+        HttpSession session = request.getSession(false);
         Set<Map.Entry<String, Object>> set = new HashSet<Map.Entry<String, Object>>();
-        Enumeration<String> keys = session.getAttributeNames();
-        String key;
-        while (keys.hasMoreElements()) {
-            key = keys.nextElement();
-            set.add(new MapEntry<String, Object>(key,
-                    session.getAttribute(key), true));
+        if (session != null) {
+            Enumeration<String> keys = session.getAttributeNames();
+            String key;
+            while (keys.hasMoreElements()) {
+                key = keys.nextElement();
+                set.add(new MapEntry<String, Object>(key,
+                        session.getAttribute(key), true));
+            }
         }
         return (set);
     }
@@ -108,18 +119,33 @@
 
     /** {@inheritDoc} */
     public boolean equals(Object o) {
-        return (session.equals(o));
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return o == null;
+        } else {
+            return (session.equals(o));
+        }
     }
 
 
     /** {@inheritDoc} */
     public Object get(Object key) {
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return null;
+        }
+
         return (session.getAttribute(key(key)));
     }
 
 
     /** {@inheritDoc} */
     public int hashCode() {
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return 0;
+        }
+
         return (session.hashCode());
     }
 
@@ -133,10 +159,13 @@
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     public Set<String> keySet() {
+        HttpSession session = request.getSession(false);
         Set<String> set = new HashSet<String>();
-        Enumeration<String> keys = session.getAttributeNames();
-        while (keys.hasMoreElements()) {
-            set.add(keys.nextElement());
+        if (session != null) {
+            Enumeration<String> keys = session.getAttributeNames();
+            while (keys.hasMoreElements()) {
+                set.add(keys.nextElement());
+            }
         }
         return (set);
     }
@@ -144,6 +173,7 @@
 
     /** {@inheritDoc} */
     public Object put(String key, Object value) {
+        HttpSession session = request.getSession();
         if (value == null) {
             return (remove(key));
         }
@@ -156,6 +186,7 @@
 
     /** {@inheritDoc} */
     public void putAll(Map<? extends String, ? extends Object> map) {
+        HttpSession session = request.getSession();
         Iterator<? extends String> keys = map.keySet().iterator();
         while (keys.hasNext()) {
             String key = keys.next();
@@ -166,6 +197,11 @@
 
     /** {@inheritDoc} */
     public Object remove(Object key) {
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return null;
+        }
+
         String skey = key(key);
         Object previous = session.getAttribute(skey);
         session.removeAttribute(skey);
@@ -176,11 +212,14 @@
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     public int size() {
+        HttpSession session = request.getSession(false);
         int n = 0;
-        Enumeration<String> keys = session.getAttributeNames();
-        while (keys.hasMoreElements()) {
-            keys.nextElement();
-            n++;
+        if (session != null) {
+            Enumeration<String> keys = session.getAttributeNames();
+            while (keys.hasMoreElements()) {
+                keys.nextElement();
+                n++;
+            }
         }
         return (n);
     }
@@ -189,10 +228,13 @@
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     public Collection<Object> values() {
+        HttpSession session = request.getSession(false);
         List<Object> list = new ArrayList<Object>();
-        Enumeration<String> keys = session.getAttributeNames();
-        while (keys.hasMoreElements()) {
-            list.add(session.getAttribute(keys.nextElement()));
+        if (session != null) {
+            Enumeration<String> keys = session.getAttributeNames();
+            while (keys.hasMoreElements()) {
+                list.add(session.getAttribute(keys.nextElement()));
+            }
         }
         return (list);
     }
@@ -46,30 +47,36 @@
      * Constructor.
      *
-     * @param session The session object to use.
+     * @param request The request object to use.
      */
@@ -46,30 +47,36 @@
     /**
-     * The session object to use.
+     * The request object to use.
      */

Modified: tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletTilesRequestContext.java
URL: http://svn.apache.org/viewvc/tiles/framework/branches/TILES_2_0_X/tiles-core/src/main/java/org/apache/tiles/servlet/context/ServletTilesRequestContext.java?rev=573651&r1=573650&r2=573651&view=diff
==============================================================================